package org.jeecg.modules.travelAddress.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.travelAddress.entity.TravelAddress;
import org.jeecg.modules.travelAddress.service.ITravelAddressService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 地址表
 * @Author: jeecg-boot
 * @Date:   2024-09-24
 * @Version: V1.0
 */
@Api(tags="地址表")
@RestController
@RequestMapping("/travelAddress/travelAddress")
@Slf4j
public class TravelAddressController extends JeecgController<TravelAddress, ITravelAddressService> {
	@Autowired
	private ITravelAddressService travelAddressService;
	
	/**
	 * 分页列表查询
	 *
	 * @param travelAddress
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "地址表-分页列表查询")
	@ApiOperation(value="地址表-分页列表查询", notes="地址表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TravelAddress>> queryPageList(TravelAddress travelAddress,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TravelAddress> queryWrapper = QueryGenerator.initQueryWrapper(travelAddress, req.getParameterMap());
		Page<TravelAddress> page = new Page<TravelAddress>(pageNo, pageSize);
		IPage<TravelAddress> pageList = travelAddressService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param travelAddress
	 * @return
	 */
	@AutoLog(value = "地址表-添加")
	@ApiOperation(value="地址表-添加", notes="地址表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TravelAddress travelAddress) {
		travelAddressService.save(travelAddress);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param travelAddress
	 * @return
	 */
	@AutoLog(value = "地址表-编辑")
	@ApiOperation(value="地址表-编辑", notes="地址表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TravelAddress travelAddress) {
		travelAddressService.updateById(travelAddress);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "地址表-通过id删除")
	@ApiOperation(value="地址表-通过id删除", notes="地址表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		travelAddressService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "地址表-批量删除")
	@ApiOperation(value="地址表-批量删除", notes="地址表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.travelAddressService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "地址表-通过id查询")
	@ApiOperation(value="地址表-通过id查询", notes="地址表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TravelAddress> queryById(@RequestParam(name="id",required=true) String id) {
		TravelAddress travelAddress = travelAddressService.getById(id);
		if(travelAddress==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(travelAddress);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param travelAddress
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TravelAddress travelAddress) {
        return super.exportXls(request, travelAddress, TravelAddress.class, "地址表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TravelAddress.class);
    }

}
