package org.jeecg.modules.travelExperience.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.travelExperience.entity.TravelExperience;
import org.jeecg.modules.travelExperience.service.ITravelExperienceService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 非遗体验表
 * @Author: jeecg-boot
 * @Date:   2024-09-24
 * @Version: V1.0
 */
@Api(tags="非遗体验表")
@RestController
@RequestMapping("/travelExperience/travelExperience")
@Slf4j
public class TravelExperienceController extends JeecgController<TravelExperience, ITravelExperienceService> {
	@Autowired
	private ITravelExperienceService travelExperienceService;
	
	/**
	 * 分页列表查询
	 *
	 * @param travelExperience
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "非遗体验表-分页列表查询")
	@ApiOperation(value="非遗体验表-分页列表查询", notes="非遗体验表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TravelExperience>> queryPageList(TravelExperience travelExperience,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TravelExperience> queryWrapper = QueryGenerator.initQueryWrapper(travelExperience, req.getParameterMap());
		Page<TravelExperience> page = new Page<TravelExperience>(pageNo, pageSize);
		IPage<TravelExperience> pageList = travelExperienceService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param travelExperience
	 * @return
	 */
	@AutoLog(value = "非遗体验表-添加")
	@ApiOperation(value="非遗体验表-添加", notes="非遗体验表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TravelExperience travelExperience) {
		travelExperienceService.save(travelExperience);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param travelExperience
	 * @return
	 */
	@AutoLog(value = "非遗体验表-编辑")
	@ApiOperation(value="非遗体验表-编辑", notes="非遗体验表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TravelExperience travelExperience) {
		travelExperienceService.updateById(travelExperience);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "非遗体验表-通过id删除")
	@ApiOperation(value="非遗体验表-通过id删除", notes="非遗体验表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		travelExperienceService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "非遗体验表-批量删除")
	@ApiOperation(value="非遗体验表-批量删除", notes="非遗体验表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.travelExperienceService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "非遗体验表-通过id查询")
	@ApiOperation(value="非遗体验表-通过id查询", notes="非遗体验表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TravelExperience> queryById(@RequestParam(name="id",required=true) String id) {
		TravelExperience travelExperience = travelExperienceService.getById(id);
		if(travelExperience==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(travelExperience);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param travelExperience
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TravelExperience travelExperience) {
        return super.exportXls(request, travelExperience, TravelExperience.class, "非遗体验表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TravelExperience.class);
    }

}
